@@ -1,5 +1,6 @@
 #!/usr/bin/env python
 import sys
+import os
 import logging
 import types
 import io
@@ -21,7 +22,7 @@ else:
 # ====================== Metadata ======================
 
 __author__ = 'John Torakis - operatorequals'
-__version__ = '1.0.0'
+__version__ = '1.1.0'
 __github__ = 'https://github.com/operatorequals/httpimport'
 
 # ====================== Constants ======================
@@ -69,6 +70,10 @@ headers:
 # tls-passphrase:
 """.format(version=__version__, homepage=__github__)
 
+__HOME_DIR = os.path.expanduser('~')
+_DEFAULT_INI_CONFIG_FILENAME = __HOME_DIR + os.sep + ".httpimport.ini"
+_DEFAULT_INI_CONFIG_DIR_NAME = __HOME_DIR + os.sep + ".httpimport"
+
 CONFIG = ConfigParser()
 if LEGACY:
     CONFIG.readfp(io.BytesIO(_DEFAULT_INI_CONFIG))
@@ -120,13 +125,9 @@ def http(url, headers={}, method='GET', proxy=None):
     try:
         resp = _urlopen(req)
         try:  # Python2 Approach
-            headers = {  # Parse Header List to Dict
-                h.split(':', 1)[0].lower(): h.split(':', 1)[1].strip()
-                for h in resp.info().__dict__["headers"]
-            }
-        except KeyError:  # Python3 Approach
-            headers = {k.lower(): v for k, v in resp.info().__dict__[
-                "_headers"]}
+            headers = {k.lower(): v for k, v in resp.headers.dict.items()}
+        except AttributeError:  # Python3 Approach
+            headers = {k.lower(): v for k, v in resp.getheaders()}
 
         return {'code': resp.code, 'body': resp.read(), 'headers': headers}
     except HTTPError as he:
@@ -249,18 +250,27 @@ class HttpImporter(object):
         proxy (str): The URL for the HTTP proxy to be used for all requests
     """
 
-    def __init__(self, url, zip_pwd=b'', headers={}, proxy=None, allow_plaintext=False):
+    def __init__(
+            self,
+            url,
+            zip_pwd=b'',
+            headers={},
+            proxy=None,
+            allow_plaintext=False):
         # remove trailing '/' from URL parameter
         self.url = url if not url.endswith('/') else url[:-1]
         self.modules = {}
 
         if not _isHTTPS(url):
-            logger.warning("[-] Using HTTP URLs (%s) with 'httpimport' is a security hazard!" % (url))
+            logger.warning(
+                "[-] Using HTTP URLs (%s) with 'httpimport' is a security hazard!" %
+                (url))
             if not (allow_plaintext or INSECURE):
                 logger.error(""" [*]
 Using plaintext protocols needs to be enabled through 'INSECURE' global or explicitly allowed through 'allow-plaintext'!
                 """)
-                raise ImportError("[-] HTTP used while plaintext is not allowed")
+                raise ImportError(
+                    "[-] HTTP used while plaintext is not allowed")
 
         self.zip_pwd = zip_pwd
         self.headers = headers
@@ -481,8 +491,14 @@ def __extract_profile_options(url=None, profile=None):
     }
 
     # Parse Plaintext Flag
-    allow_plaintext = options['allow-plaintext'].lower() in ['true', 'yes', '1']
-    return {'headers': headers, 'proxy': proxy, 'url': url, 'zip_pwd': zip_pwd, 'allow-plaintext': allow_plaintext}
+    allow_plaintext = options['allow-plaintext'].lower() in ['true',
+                                                             'yes', '1']
+    return {
+        'headers': headers,
+        'proxy': proxy,
+        'url': url,
+        'zip_pwd': zip_pwd,
+        'allow-plaintext': allow_plaintext}
 
 # ====================== Features ======================
 
@@ -512,7 +528,7 @@ def add_remote_repo(url=None, profile=None):
         proxy=options['proxy'],
         zip_pwd=options['zip_pwd'],
         allow_plaintext=options['allow-plaintext'],
-        )
+    )
     sys.meta_path.append(importer)
     return importer
 
@@ -640,7 +656,7 @@ def load(module_name, url=None, profile=None):
         proxy=options['proxy'],
         zip_pwd=options['zip_pwd'],
         allow_plaintext=options['allow-plaintext'],
-        )
+    )
     return importer._create_module(module_name, sys_modules=False)
     raise ImportError(
         "Module '%s' cannot be imported from URL: '%s'" % (module_name, url))
@@ -651,6 +667,27 @@ def load(module_name, url=None, profile=None):
 # Load the catch-all configuration
 set_profile(_DEFAULT_INI_CONFIG)
 
+# Try to load the user config file
+try:
+    with open(_DEFAULT_INI_CONFIG_FILENAME) as f:
+        logger.info(
+            "[*] Loading configuration from '%s'" %
+            _DEFAULT_INI_CONFIG_FILENAME)
+        set_profile(f.read())
+except IOError: # Not using FileNotFoundError - Python2 compatibility
+    logger.info("[*] File '%s' not available." % _DEFAULT_INI_CONFIG_FILENAME)
+
+# Try to load the user config directory
+try:
+    for config_file in os.listdir(_DEFAULT_INI_CONFIG_DIR_NAME):
+        with open(config_file) as f:
+            logger.info("[*] Loading configuration from '%s'" % config_file)
+            set_profile(f.read())
+except OSError: # Not using FileNotFoundError - Python2 compatibility
+    logger.info(
+        "[*] Directory '%s' not available." %
+        _DEFAULT_INI_CONFIG_DIR_NAME)
+
 # ====================== Main ======================
 
 if __name__ == '__main__':
